@@ -1,8 +1,11 @@
 import functools
 import operator
+import pickle
 import sys
+from collections import OrderedDict
 from io import BytesIO
 
+import env
 import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
@@ -10,15 +13,6 @@ from pytest import approx
 
 import boost_histogram as bh
 
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-
-from collections import OrderedDict
-
-import env
-
 
 def test_init():
     bh.Histogram()
@@ -152,12 +146,8 @@ def test_fill_1d(flow):
         assert get(h, bh.overflow) == 1
 
 
-@pytest.mark.parametrize(
-    "storage",
-    [bh.storage.Int64, bh.storage.Double, bh.storage.Unlimited, bh.storage.AtomicInt64],
-)
-def test_setting(storage):
-    h = bh.Histogram(bh.axis.Regular(10, 0, 1), storage=storage())
+def test_setting(count_single_storage):
+    h = bh.Histogram(bh.axis.Regular(10, 0, 1), storage=count_single_storage())
     h[bh.underflow] = 1
     h[0] = 2
     h[1] = 3
@@ -403,6 +393,50 @@ def test_add_2d_w(flow):
             assert h[bh.tag.at(i), bh.tag.at(j)] == 2 * m[i][j]
 
 
+def test_sub_2d(flow, count_storage):
+
+    h0 = bh.Histogram(
+        bh.axis.Integer(-1, 2, underflow=flow, overflow=flow),
+        bh.axis.Regular(4, -2, 2, underflow=flow, overflow=flow),
+        storage=count_storage(),
+    )
+
+    h0.fill(-1, -2)
+    h0.fill(-1, -1)
+    h0.fill(0, 0)
+    h0.fill(0, 1)
+    h0.fill(1, 0)
+    h0.fill(3, -1)
+    h0.fill(0, -3)
+
+    m = h0.values(flow=True).copy()
+
+    if count_storage not in {bh.storage.AtomicInt64, bh.storage.Weight}:
+        h = h0.copy()
+        h -= h0
+        assert h.values(flow=True) == approx(m * 0)
+
+        h -= h0
+        assert h.values(flow=True) == approx(-m)
+
+        h2 = h0 - (h0 + h0 + h0)
+        assert h2.values(flow=True) == approx(-2 * m)
+
+    h3 = h0 - h0.view(flow=True) * 4
+    assert h3.values(flow=True) == approx(-3 * m)
+
+    h4 = h0.copy()
+    h4 -= h0.view(flow=True) * 5
+    assert h4.values(flow=True) == approx(-4 * m)
+
+    h5 = h0.copy()
+    h5 -= 2
+    assert h5.values(flow=True) == approx(m - 2)
+
+    h6 = h0 - 3
+    assert h6.values(flow=True) == approx(m - 3)
+
+
 def test_repr():
     hrepr = """Histogram(
   Regular(3, 0, 1),
@@ -436,15 +470,11 @@ def test_empty_repr():
 def test_str():
     h1 = bh.Histogram(bh.axis.Regular(3, 0, 1))
     h1.view(True)[...] = [0, 1, 3, 2, 1]
-    assert repr(str(h1)) == repr(
-        """                   +---------------------------------------------------------+
-[  -inf,      0) 0 |                                                         |
-[     0, 0.3333) 1 |===================                                      |
-[0.3333, 0.6667) 3 |======================================================== |
-[0.6667,      1) 2 |=====================================                    |
-[     1,    inf) 1 |===================                                      |
-                   +---------------------------------------------------------+"""
-    )
+    current_repr = repr(str(h1))
+
+    assert "[  -inf,      0)" in current_repr
+    assert "[0.3333, 0.6667) 3" in current_repr
+    assert "[     1,    inf)" in current_repr
 
     h2 = bh.Histogram(bh.axis.Regular(3, 0, 1), bh.axis.Integer(0, 1))
     assert repr(str(h2)) == repr(repr(h2))
@@ -737,7 +767,7 @@ def test_pickle_bool():
     assert_array_equal(a.view(), b.view())
 
 
-# Numpy tests
+# NumPy tests
 
 
 def test_numpy_conversion_0():
@@ -1178,7 +1208,7 @@ def test_add_broadcast():
 
     h2 = h + [[1]]
     assert h2.sum() == 10 * 20
-    assert h2.sum(flow=True) == 10 * 20
+    assert h2.sum(flow=True) == 12 * 22
 
     h3 = h + np.ones((10, 20))
     assert h3.sum() == 10 * 20
@@ -1234,3 +1264,30 @@ def test_np_scalars():
 
     hist /= np.float64(2.0)
     assert hist[bh.loc(7)] == 1.0
+
+
+def test_sum_empty_axis():
+    hist = bh.Histogram(
+        bh.axis.StrCategory("", growth=True),
+        bh.axis.Regular(10, 0, 1),
+        storage=bh.storage.Weight(),
+    )
+    assert hist.sum().value == 0
+    assert "Str" in repr(hist)
+
+
+# Issue #618
+def test_negative_fill(count_storage):
+    h = bh.Histogram(bh.axis.Integer(0, 3), storage=count_storage())
+    h.fill(1, weight=-1)
+
+    answer = np.array([0, -1, 0])
+    assert h.values() == approx(answer)
+
+
+# Issue #589
+def test_underfill_growth():
+    h = bh.Histogram(bh.axis.Regular(10, 0, 1, growth=True))
+    h.fill(2)
+    h.fill(-1)
+    assert h.sum() == 2
